# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Option'
        db.create_table('options_option', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('key', self.gf('django.db.models.fields.CharField')(max_length=50, db_index=True)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=256)),
        ))
        db.send_create_signal('options', ['Option'])


    def backwards(self, orm):
        # Deleting model 'Option'
        db.delete_table('options_option')


    models = {
        'options.option': {
            'Meta': {'ordering': "['key']", 'object_name': 'Option'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'max_length': '50', 'db_index': 'True'}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '256'})
        }
    }

    complete_apps = ['options']


# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'Text'
        db.create_table('options_text', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('key', self.gf('django.db.models.fields.CharField')(unique=True, max_length=50)),
            ('value', self.gf('django.db.models.fields.TextField')()),
        ))
        db.send_create_signal('options', ['Text'])

        # Adding model 'Label'
        db.create_table('options_label', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('key', self.gf('django.db.models.fields.CharField')(unique=True, max_length=50)),
            ('value', self.gf('django.db.models.fields.CharField')(max_length=256)),
        ))
        db.send_create_signal('options', ['Label'])

        # Removing index on 'Option', fields ['key']
        db.delete_index('options_option', ['key'])

        # Adding unique constraint on 'Option', fields ['key']
        db.create_unique('options_option', ['key'])


    def backwards(self, orm):
        # Removing unique constraint on 'Option', fields ['key']
        db.delete_unique('options_option', ['key'])

        # Adding index on 'Option', fields ['key']
        db.create_index('options_option', ['key'])

        # Deleting model 'Text'
        db.delete_table('options_text')

        # Deleting model 'Label'
        db.delete_table('options_label')


    models = {
        'options.label': {
            'Meta': {'ordering': "['key']", 'object_name': 'Label'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50'}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '256'})
        },
        'options.option': {
            'Meta': {'ordering': "['key']", 'object_name': 'Option'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50'}),
            'value': ('django.db.models.fields.CharField', [], {'max_length': '256'})
        },
        'options.text': {
            'Meta': {'ordering': "['key']", 'object_name': 'Text'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'key': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '50'}),
            'value': ('django.db.models.fields.TextField', [], {})
        }
    }

    complete_apps = ['options']


from modeltranslation.translator import translator, TranslationOptions
from options.models import Label, Text

class QOptionsTranslationOptions(TranslationOptions):
    fields = ('value',)

translator.register(Label, QOptionsTranslationOptions)
translator.register(Text,  QOptionsTranslationOptions)



from django.db import models
from django.utils.translation import ugettext_lazy as _


class OptionCache(object):
    _cache = {}

    @staticmethod
    def get(key):
        try:
            return OptionCache._cache[key]
        except:
            return None

    @staticmethod
    def set(key, value):
        OptionCache._cache[key] = value

    @staticmethod
    def delete(key):
        del OptionCache._cache[key]


class Option(models.Model):
    """
    Options model
    """
    key = models.CharField(_('Key'), max_length=50, unique=True)
    value = models.CharField(_('Value'), max_length=256)

    cache_mask = 'qo_o_{0}'

    class Meta:
        verbose_name = _('option')
        verbose_name_plural = _('options')
        ordering = ['key']

    def __unicode__(self):
        return self.key

    def save(self, *args, **kwargs):
        super(Option, self).save(*args, **kwargs)
        try:
            OptionCache.delete(Option.cache_mask.format(self.key))
        except KeyError:
            pass


class Label(models.Model):
    key = models.CharField(_('Key'), max_length=50, unique=True)
    value = models.CharField(_('Value'), max_length=256)

    cache_mask = 'qo_l_{0}'

    class Meta:
        verbose_name = _('label')
        verbose_name_plural = _('labels')
        ordering = ['key']

    def __unicode__(self):
        return self.key

    def save(self, *args, **kwargs):
        super(Label, self).save(*args, **kwargs)
        try:
            OptionCache.delete(Label.cache_mask.format(self.key))
        except KeyError:
            pass


class Text(models.Model):
    key = models.CharField(_('Key'), max_length=50, unique=True)
    value = models.TextField(_('Value'))

    cache_mask = 'qo_t_{0}'

    class Meta:
        verbose_name = _('text')
        verbose_name_plural = _('texts')
        ordering = ['key']

    def __unicode__(self):
        return self.key

    def save(self, *args, **kwargs):
        super(Text, self).save(*args, **kwargs)
        try:
            OptionCache.delete(Text.cache_mask.format(self.key))
        except KeyError:
            pass
